@@ -1109,6 +1109,8 @@ ypresp_maplist *ypproc_maplist_2_svc(domainname *name,
     
     result.maps = NULL;
 
+    result.stat = YP_TRUE;
+
     if ((*name)[0] == '\0')
 	result.stat = YP_BADARGS;
     else if (!is_valid_domain(*name))
@@ -1117,7 +1119,9 @@ ypresp_maplist *ypproc_maplist_2_svc(domainname *name,
     {
 	DIR *dp;
 
-	dp = opendir(".");
+	fprintf( stderr, "Reading dir %s\n", *name);
+	/* open domain directory */
+	dp = opendir( *name);
 	if (dp == NULL)
 	{
 	    if (debug_flag)
@@ -1132,13 +1136,17 @@ ypresp_maplist *ypproc_maplist_2_svc(domainname *name,
 	{
 	    struct dirent *dep;
 	    
-	    while ((dep = readdir(dp)) != NULL)
+	    while ((dep = readdir(dp)) != NULL) {
+	        /* ignore files . and .. */
+	        if (strcmp( ".", dep->d_name) == 0 ||
+		    strcmp( "..", dep->d_name) == 0)
+		  continue;
 		if (add_maplist(&result.maps, dep->d_name) < 0)
 		{
 		    result.stat = YP_YPERR;
 		    break;
 		}
-	    
+	    }
 	    closedir(dp);
 	}
     }
@@ -1154,8 +1162,10 @@ ypresp_maplist *ypproc_maplist_2_svc(domainname *name,
 	    while (p)
 	    {
 		fprintf(stderr, "%s", p->map);
-		if (p->next)
+		if (p->next) {
 		    fprintf(stderr, ", ");
+		}
+		p = p->next;
 	    }
 	    putc('\n', stderr);
 	}
